==> jc-1.4.0.tar.gz: javax/print/attribute/standard/PrinterMoreInfoManufacturer.h <==
// public final class javax.print.attribute.standard.PrinterMoreInfoManufacturer

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bc4a0dc2546ead9f javax_print_attribute_URISyntax
// @dep_class 1ba550447e28a737 javax_print_attribute_standard_PrinterMoreInfoManufacturer

// header file dependencies
// @dep_header javax_print_attribute_URISyntax

#include "javax/print/attribute/URISyntax.h"

#ifndef _JC_javax_print_attribute_standard_PrinterMoreInfoManufacturer_H_
#define _JC_javax_print_attribute_standard_PrinterMoreInfoManufacturer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URI$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_refs	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_nonrefs	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$refs	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$refs;
typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$nonrefs	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object;

typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$fields_struct	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vmethods	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtable	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtype	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrinterMoreInfoManufacturer;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$fields_struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method$_init$7c3d63594f030366(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object *, struct _jc_java_net_URI$object *);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_URISyntax$vmethods	javax_print_attribute_URISyntax;
	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vmethods	javax_print_attribute_standard_PrinterMoreInfoManufacturer;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$refs {
    _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_refs	javax_print_attribute_standard_PrinterMoreInfoManufacturer;
    _jc_javax_print_attribute_URISyntax$sub_refs	javax_print_attribute_URISyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_URISyntax$sub_nonrefs	javax_print_attribute_URISyntax;
    _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_nonrefs	javax_print_attribute_standard_PrinterMoreInfoManufacturer;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object {
	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtype _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrinterMoreInfoManufacturer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrinterMoreInfoManufacturer_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/PrinterMoreInfoManufacturer.h <==
// public final class javax.print.attribute.standard.PrinterMoreInfoManufacturer

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bc4a0dc2546ead9f javax_print_attribute_URISyntax
// @dep_class 1ba550447e28a737 javax_print_attribute_standard_PrinterMoreInfoManufacturer

// header file dependencies
// @dep_header javax_print_attribute_URISyntax

#include "javax/print/attribute/URISyntax.h"

#ifndef _JC_javax_print_attribute_standard_PrinterMoreInfoManufacturer_H_
#define _JC_javax_print_attribute_standard_PrinterMoreInfoManufacturer_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URI$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_refs	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_nonrefs	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$refs	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$refs;
typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$nonrefs	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object;

typedef struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$fields_struct	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vmethods	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtable	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtype	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrinterMoreInfoManufacturer;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$fields_struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method$_init$7c3d63594f030366(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object *, struct _jc_java_net_URI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_URISyntax$vmethods	javax_print_attribute_URISyntax;
	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vmethods	javax_print_attribute_standard_PrinterMoreInfoManufacturer;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$refs {
    _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_refs	javax_print_attribute_standard_PrinterMoreInfoManufacturer;
    _jc_javax_print_attribute_URISyntax$sub_refs	javax_print_attribute_URISyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_URISyntax$sub_nonrefs	javax_print_attribute_URISyntax;
    _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$sub_nonrefs	javax_print_attribute_standard_PrinterMoreInfoManufacturer;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$object {
	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$vtype _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrinterMoreInfoManufacturer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrinterMoreInfoManufacturer$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrinterMoreInfoManufacturer_H_ */
